redraw/dom/attribute/aria
ARIA attributes, used to improve accessibility of HTML and SVG elements.
When an attribute is not available here, fallback on attribute.aria.
All available attributes can be found in the MDN documentation.
Values
pub fn aria(key: String, value: String) -> attribute.Attribute
pub fn braille_role_description(
value: String,
) -> attribute.Attribute
pub fn key_shortcuts(
shortcuts: List(String),
) -> attribute.Attribute