redraw/dom/event/drag

The DragEvent interface is a DOM event that represents a drag and drop interaction. The user initiates a drag by placing a pointer device (such as a mouse) on the touch surface and then dragging the pointer to a new location (such as another DOM element). Applications are free to interpret a drag and drop interaction in an application-specific way.

Drag and Drop API Documentation

Types

Values

pub fn as_event(event: DragEvent) -> event.Event

DragEvent inherits Event.

pub fn as_mouse_event(event: DragEvent) -> mouse.MouseEvent

DragEvent inherits from MouseEvent.

pub fn as_ui_event(event: DragEvent) -> ui.UIEvent

DragEvent inherits from UIEvent.

Search Document